@@ -139,9 +139,11 @@ def generate_mappings():
         return (x_months_ago_check(activity, groups[0], groups[3]) or 
                 x_months_ago_check(activity, groups[1], groups[3], groups[2]))
 
-    @add_partial('(\S*) or (\S*) is less than (\S*) months? ago\?')
+    @add_partial('(\S*) or (\S*) or (\S*) or (\S*) is less than (\S*) months? ago\?')
     def less_than_x_months_ago(activity, groups):
-        return (x_months_ago_check(activity, groups[0], groups[2]) or 
-                x_months_ago_check(activity, groups[1], groups[2]))
+        return (x_months_ago_check(activity, groups[0], groups[4]) or 
+                x_months_ago_check(activity, groups[1], groups[4]) or 
+                x_months_ago_check(activity, groups[2], groups[4]) or 
+                x_months_ago_check(activity, groups[3], groups[4]))
 
     return mappings
